@@ -850,7 +850,11 @@ finish:
 	_debug( "vprintf size %u\n", size );
 #endif
 	Newx( tmp, size, char );
+#ifdef _WIN32
+	size = _vsnprintf( tmp, size, fmt, vl );
+#else
 	size = vsnprintf( tmp, size, fmt, vl );
+#endif
 #ifdef SC_DEBUG
 	_debug( "vprintf size %u\n", size );
 #endif
@@ -1048,8 +1052,8 @@ _default:
 		}
 		if( serv != NULL && *serv != '\0' ) {
 			if( serv[0] >= '0' && serv[0] <= '9' )
-				((struct sockaddr_in *) addr->a)->sin_port
-					= htons( atoi( serv ) );
+				((struct sockaddr_in *) addr->a)->sin_port =
+					htons( atoi( serv ) );
 			else {
 				struct servent *se;
 				se = getservbyname( serv, NULL );
@@ -1217,8 +1221,6 @@ int mod_sc_gethostbyaddr(
 	int r;
 #else
 	struct hostent *he;
-	struct in_addr ia4;
-	struct in6_addr ia6;
 	char *s2;
 #endif
 	if( addr == NULL )
@@ -1246,13 +1248,13 @@ int mod_sc_gethostbyaddr(
 	case AF_INET:
 		he = gethostbyaddr(
 			(const char *) &((struct sockaddr_in *) addr->a)->sin_addr,
-			sizeof( ia4 ), AF_INET
+			sizeof( struct in_addr ), AF_INET
 		);
 		break;
 	case AF_INET6:
 		he = gethostbyaddr(
 			(const char *) &((struct sockaddr_in6 *) addr->a)->sin6_addr,
-			sizeof( ia6 ), AF_INET6
+			sizeof( struct in6_addr ), AF_INET6
 		);
 		break;
 	default:
@@ -2101,11 +2103,19 @@ void mod_sc_set_error( sc_t *sock, int code, const char *fmt, ... ) {
 	va_start( vl, fmt );
 	if( sock != NULL ) {
 		sock->last_errno = code;
+#ifdef _WIN32
+		_vsnprintf( sock->last_error, sizeof(sock->last_error), fmt, vl );
+#else
 		vsnprintf( sock->last_error, sizeof(sock->last_error), fmt, vl );
+#endif
 	}
 	else {
 		global.last_errno = code;
+#ifdef _WIN32
+		_vsnprintf( global.last_error, sizeof(global.last_error), fmt, vl );
+#else
 		vsnprintf( global.last_error, sizeof(global.last_error), fmt, vl );
+#endif
 	}
 	va_end( vl );
 }
